@@ -1,5 +1,5 @@
 document.getElementById("Contents").innerHTML='\
-    <ul><li><input type="checkbox" id="07"><label for="07">Fjölvar og forritun</label><ul>\
+    <ul><li><input type="checkbox" id="07"><label for="07">Fjölvar og skriftur</label><ul>\
     <li><input type="checkbox" id="0701"><label for="0701">Almennar upplýsingar og notkun notandaviðmóts</label><ul>\
     <li><a target="_top" href="is/text/sbasic/shared/main0601.html">LibreOffice Basic Help</a></li>\
     <li><a target="_top" href="is/text/sbasic/shared/01000000.html">Programming with LibreOffice Basic</a></li>\
@@ -17,7 +17,7 @@ document.getElementById("Contents").innerHTML='\
     <li><input type="checkbox" id="0702"><label for="0702">Tilvísanir í skipanir</label><ul>\
     <li><a target="_top" href="is/text/sbasic/shared/01020300.html">Using Procedures and Functions</a></li>\
     <li><a target="_top" href="is/text/sbasic/shared/01020500.html">Libraries, Modules and Dialogs</a></li>\
-    <li><input type="checkbox" id="070202"><label for="070202">Functions, Statements, and Operators</label><ul>\
+    <li><input type="checkbox" id="070202"><label for="070202">Föll, skipanasetningar og virkjar</label><ul>\
     <li><a target="_top" href="is/text/sbasic/shared/03010000.html">Screen I/O Functions</a></li>\
     <li><a target="_top" href="is/text/sbasic/shared/03020000.html">File I/O Functions</a></li>\
     <li><a target="_top" href="is/text/sbasic/shared/03030000.html">Date and Time Functions</a></li>\
@@ -124,6 +124,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="is/text/sbasic/shared/03090202.html">For...Next Statement</a></li>\
     <li><a target="_top" href="is/text/sbasic/shared/03120301.html">Format Function</a></li>\
     <li><a target="_top" href="is/text/sbasic/shared/03150000.html">FormatDateTime Function [VBA]</a></li>\
+    <li><a target="_top" href="is/text/sbasic/shared/03170010.html">FormatNumber Function [VBA]</a></li>\
     <li><a target="_top" href="is/text/sbasic/shared/03020102.html">FreeFile Function</a></li>\
     <li><a target="_top" href="is/text/sbasic/shared/03090405.html">FreeLibrary Function</a></li>\
     <li><a target="_top" href="is/text/sbasic/shared/03090406.html">Function Statement</a></li>\
@@ -271,7 +272,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="is/text/sbasic/shared/03070400.html">"/" Operator</a></li>\
     <li><a target="_top" href="is/text/sbasic/shared/03070500.html">"^" Operator</a></li>\
 			</ul></li>\
-    <li><input type="checkbox" id="070205"><label for="070205">Advanced Basic Libraries</label><ul>\
+    <li><input type="checkbox" id="070205"><label for="070205">Ítarleg grunnaðgerðasöfn</label><ul>\
     <li><a target="_top" href="is/text/sbasic/shared/03/lib_tools.html">Tools Library</a></li>\
     <li><a target="_top" href="is/text/sbasic/shared/03/lib_depot.html">DEPOT Library</a></li>\
     <li><a target="_top" href="is/text/sbasic/shared/03/lib_euro.html">EURO Library</a></li>\
@@ -297,7 +298,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="is/text/sbasic/guide/access2base.html">Access2Base</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="08"><label for="08">Töflureiknar</label><ul>\
+    <ul><li><input type="checkbox" id="08"><label for="08">Töflureiknar (Calc)</label><ul>\
     <li><input type="checkbox" id="0801"><label for="0801">Almennar upplýsingar og notkun notandaviðmóts</label><ul>\
     <li><a target="_top" href="is/text/scalc/main0000.html">Velkomin í hjálpina fyrir LibreOffice Calc</a></li>\
     <li><a target="_top" href="is/text/scalc/main0503.html">Eiginleikar LibreOffice Calc</a></li>\
@@ -419,7 +420,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="is/text/scalc/guide/datapilot_tipps.html">Selecting Pivot Table Output Ranges</a></li>\
     <li><a target="_top" href="is/text/scalc/guide/datapilot_updatetable.html">Updating Pivot Tables</a></li>\
 		</ul></li>\
-    <li><input type="checkbox" id="08091"><label for="08091">Pivot Chart</label><ul>\
+    <li><input type="checkbox" id="08091"><label for="08091">Veltiröflulínurit</label><ul>\
     <li><a target="_top" href="is/text/scalc/guide/pivotchart.html">Pivot Chart</a></li>\
     <li><a target="_top" href="is/text/scalc/guide/pivotchart_create.html">Creating Pivot Charts</a></li>\
     <li><a target="_top" href="is/text/scalc/guide/pivotchart_edit.html">Editing Pivot Charts</a></li>\
@@ -477,7 +478,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="is/text/schart/04/01020000.html">Flýtilyklar í gröfum</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="01"><label for="01">Uppsetning</label><ul>\
+    <ul><li><input type="checkbox" id="01"><label for="01">Uppsetning LibreOffice</label><ul>\
     <li><a target="_top" href="is/text/shared/guide/ms_doctypes.html">Breyta skráavenslum við Microsoft Office skjalagerðir</a></li>\
     <li><a target="_top" href="is/text/shared/01/profile_safe_mode.html">Safe Mode</a></li>\
 	</ul></li></ul>\
@@ -503,7 +504,6 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="is/text/shared/optionen/01010200.html">Almennt</a></li>\
     <li><a target="_top" href="is/text/shared/optionen/01010300.html">Slóðir</a></li>\
     <li><a target="_top" href="is/text/shared/optionen/01010400.html">Hjálparforrit</a></li>\
-    <li><a target="_top" href="is/text/shared/optionen/01010500.html">Color</a></li>\
     <li><a target="_top" href="is/text/shared/optionen/01010600.html">Almennt</a></li>\
     <li><a target="_top" href="is/text/shared/optionen/01010700.html">Letur</a></li>\
     <li><a target="_top" href="is/text/shared/optionen/01010800.html">Skoða</a></li>\
@@ -567,7 +567,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="is/text/shared/guide/textmode_change.html">Switching Between Insert Mode and Overwrite Mode</a></li>\
     <li><a target="_top" href="is/text/shared/guide/floating_toolbar.html">Using Toolbars</a></li>\
 		</ul></li>\
-    <li><input type="checkbox" id="10071"><label for="10071">Digital Signatures</label><ul>\
+    <li><input type="checkbox" id="10071"><label for="10071">Stafrænar undirritanir</label><ul>\
     <li><a target="_top" href="is/text/shared/guide/digital_signatures.html">About Digital Signatures</a></li>\
     <li><a target="_top" href="is/text/shared/guide/digitalsign_send.html">Applying Digital Signatures</a></li>\
     <li><a target="_top" href="is/text/shared/01/digitalsignaturespdf.html">Digital Signature in PDF Export</a></li>\
@@ -661,7 +661,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="is/text/shared/guide/numbering_stop.html">Turning off Bullets and Numbering for Individual Paragraphs</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="09"><label for="09">Virkni gagnagrunna</label><ul>\
+    <ul><li><input type="checkbox" id="09"><label for="09">Virkni gagnagrunns (Base)</label><ul>\
     <li><input type="checkbox" id="0901"><label for="0901">Almennar upplýsingar</label><ul>\
     <li><a target="_top" href="is/text/shared/explorer/database/main.html">LibreOffice gagnagrunnur</a></li>\
     <li><a target="_top" href="is/text/shared/guide/database_main.html">Yfirlit um gagnagrunna</a></li>\
@@ -675,7 +675,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="is/text/shared/guide/data_enter_sql.html">Executing SQL Commands</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="04"><label for="04">Kynningar og teikningar</label><ul>\
+    <ul><li><input type="checkbox" id="04"><label for="04">Kynningar og teikning (Impress/Draw)</label><ul>\
     <li><input type="checkbox" id="0401"><label for="0401">Almennar upplýsingar og notkun notandaviðmóts</label><ul>\
     <li><a target="_top" href="is/text/simpress/main0000.html">Velkomin í hjálpina fyrir LibreOffice Impress</a></li>\
     <li><a target="_top" href="is/text/sdraw/main0000.html">Velkomin í hjálpina fyrir LibreOffice Draw</a></li>\
@@ -684,7 +684,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="is/text/simpress/guide/keyboard.html">Notkun flýtilykla í LibreOffice Impress</a></li>\
     <li><a target="_top" href="is/text/sdraw/guide/keyboard.html">Flýtilyklar fyrir teiknaða hluti</a></li>\
     <li><a target="_top" href="is/text/simpress/04/01020000.html">Flýtilyklar í LibreOffice Impress</a></li>\
-    <li><a target="_top" href="is/text/simpress/04/presenter.html">Presenter Console Keyboard Shortcuts</a></li>\
+    <li><a target="_top" href="is/text/simpress/04/presenter.html">Presenter Console lyklaborðsflýtilyklar</a></li>\
     <li><a target="_top" href="is/text/sdraw/04/01020000.html">Flýtilyklar fyrir teikningar</a></li>\
     <li><a target="_top" href="is/text/simpress/guide/main.html">Leiðbeiningar fyrir notkun LibreOffice Impress</a></li>\
     <li><a target="_top" href="is/text/sdraw/guide/main.html">Leiðbeiningar fyrir notkun LibreOffice Draw</a></li>\
@@ -812,7 +812,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="is/text/simpress/guide/arrange_slides.html">Changing the Slide Order</a></li>\
     <li><a target="_top" href="is/text/simpress/guide/change_scale.html">Zooming With the Keypad</a></li>\
          </ul></li>\
-    <li><input type="checkbox" id="0411"><label for="0411">Slide Shows</label><ul>\
+    <li><input type="checkbox" id="0411"><label for="0411">Skyggnukynningar</label><ul>\
     <li><a target="_top" href="is/text/simpress/guide/show.html">Showing a Slide Show</a></li>\
     <li><a target="_top" href="is/text/simpress/guide/presenter_console.html">Using the Presenter Console</a></li>\
     <li><a target="_top" href="is/text/simpress/guide/impress_remote.html">Impress Remote Guide</a></li>\
@@ -820,7 +820,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="is/text/simpress/guide/rehearse_timings.html">Rehearse Timings of Slide Changes</a></li>\
          </ul></li>\
      </ul></li></ul>\
-    <ul><li><input type="checkbox" id="03"><label for="03">Formúlur</label><ul>\
+    <ul><li><input type="checkbox" id="03"><label for="03">Formúlur (Math)</label><ul>\
     <li><input type="checkbox" id="0301"><label for="0301">Almennar upplýsingar og notkun notandaviðmóts</label><ul>\
     <li><a target="_top" href="is/text/smath/main0000.html">Velkomin í hjálpina fyrir LibreOffice Math</a></li>\
     <li><a target="_top" href="is/text/smath/main0503.html">Eiginleikar LibreOffice Math</a></li>\
@@ -840,7 +840,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="is/text/smath/guide/parentheses.html">Inserting Brackets</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="02"><label for="02">Textaskjöl</label><ul>\
+    <ul><li><input type="checkbox" id="02"><label for="02">Textaskjöl (Writer)</label><ul>\
     <li><input type="checkbox" id="0201"><label for="0201">Almennar upplýsingar og notkun notandaviðmóts</label><ul>\
     <li><a target="_top" href="is/text/swriter/main0000.html">Velkomin í hjálpina fyrir LibreOffice Writer</a></li>\
     <li><a target="_top" href="is/text/swriter/main0503.html">Eiginleikar LibreOffice Writer</a></li>\
@@ -858,9 +858,9 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="is/text/swriter/main0103.html">Skoða</a></li>\
     <li><a target="_top" href="is/text/swriter/main0104.html">Setja inn</a></li>\
     <li><a target="_top" href="is/text/swriter/main0105.html">Sníða</a></li>\
-    <li><a target="_top" href="is/text/swriter/main0115.html">Styles</a></li>\
+    <li><a target="_top" href="is/text/swriter/main0115.html">Stílar</a></li>\
     <li><a target="_top" href="is/text/swriter/main0110.html">Tafla</a></li>\
-    <li><a target="_top" href="is/text/swriter/main0120.html">Form Menu</a></li>\
+    <li><a target="_top" href="is/text/swriter/main0120.html">Eyðublaðavalmynd</a></li>\
     <li><a target="_top" href="is/text/swriter/main0106.html">Verkfæri</a></li>\
     <li><a target="_top" href="is/text/swriter/main0107.html">Gluggi</a></li>\
     <li><a target="_top" href="is/text/shared/main0108.html">Hjálp</a></li>\
@@ -1049,7 +1049,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="is/text/shared/01/02100001.html">List of Regular Expressions</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="06"><label for="06">HTML vefskjöl</label><ul>\
+    <ul><li><input type="checkbox" id="06"><label for="06">HTML-skjöl (Writer Web)</label><ul>\
     <li><a target="_top" href="is/text/shared/07/09000000.html">Vefsíður</a></li>\
     <li><a target="_top" href="is/text/shared/02/01170700.html">HTML síur og eyðublöð</a></li>\
     <li><a target="_top" href="is/text/swriter/guide/send2html.html">Vista textaskjöl á HTML sniði</a></li>\
